ConservedWaterSearch
==============================
.. image:: https://readthedocs.org/projects/conservedwatersearch/badge/?version=latest


Module for identification of conserved water molecules from MD trajectories.

